diff libpurple/protocols/qq/sys_msg.c @ 18807:b9a0b1bd321b

Improve a bunch of strings in QQ
author Mark Doliner <mark@kingant.net>
date Mon, 06 Aug 2007 00:14:47 +0000
parents 08db93bbd798
children 953906bcd2ec 0656705131b8
line wrap: on
line diff
--- a/libpurple/protocols/qq/sys_msg.c	Sun Aug 05 19:42:29 2007 +0000
+++ b/libpurple/protocols/qq/sys_msg.c	Mon Aug 06 00:14:47 2007 +0000
@@ -80,12 +80,11 @@
 	uid = g->uid;
 	g_return_if_fail(gc != 0 && uid != 0);
 
-	qq_send_packet_get_info(gc, uid, TRUE);	/* we wanna see window */
+	qq_send_packet_get_info(gc, uid, TRUE);	/* we want to see window */
 
 	nombre = uid_to_purple_name(uid);
-	/* TODO: 'wanna' is not an appropriate word for this string. Fix after string freeze. */
 	purple_request_action
-	    (gc, NULL, _("Do you wanna approve the request?"), "", 2,
+	    (gc, NULL, _("Do you want to approve the request?"), "", 2,
 		 purple_connection_get_account(gc), nombre, NULL,
 		 g, 2,
 	     _("Reject"), G_CALLBACK(qq_reject_add_request_with_gc_and_uid),
@@ -105,11 +104,10 @@
 	uid = g->uid;
 	g_return_if_fail(gc != 0 && uid != 0);
 
-	qq_send_packet_get_info(gc, uid, TRUE);	/* we wanna see window */
-	/* TODO: 'wanna' is not an appropriate word for this string. Fix after string freeze. */
+	qq_send_packet_get_info(gc, uid, TRUE);	/* we want to see window */
 	nombre = uid_to_purple_name(uid);
 	purple_request_action
-	    (gc, NULL, _("Do you wanna add this buddy?"), "", 2,
+	    (gc, NULL, _("Do you want to add this buddy?"), "", 2,
 		 purple_connection_get_account(gc), nombre, NULL,
 		 g, 2,
 	     _("Cancel"), NULL,
@@ -175,7 +173,7 @@
 					_("Add"), G_CALLBACK(qq_add_buddy_with_gc_and_uid),
 				    _("Search"), G_CALLBACK(_qq_search_before_add_with_gc_and_uid));
 	} else {
-		message = g_strdup_printf(_("%s has added you [%s]"), from, to);
+		message = g_strdup_printf(_("%s has added you [%s] to his or her buddy list"), from, to);
 		_qq_sys_msg_log_write(gc, message, from);
 		purple_notify_info(gc, NULL, message, NULL);
 	}
@@ -211,7 +209,7 @@
 	qd = (qq_data *) gc->proto_data;
 	qq_add_buddy_by_recv_packet(gc, strtol(from, NULL, 10), TRUE, TRUE);
 
-	message = g_strdup_printf(_("User %s has approved your request"), from);
+	message = g_strdup_printf(_("User %s approved your request"), from);
 	_qq_sys_msg_log_write(gc, message, from);
 	purple_notify_info(gc, NULL, message, NULL);
 
@@ -236,9 +234,8 @@
 
 	name = uid_to_purple_name(uid);
 
-	/* TODO: 'wanna' is not an appropriate word for this string. Fix after string freeze */
 	/* TODO: this should go through purple_account_request_authorization() */
-	message = g_strdup_printf(_("%s wanna add you [%s] as friends"), from, to);
+	message = g_strdup_printf(_("%s wants to add you [%s] as a friend"), from, to);
 	reason = g_strdup_printf(_("Message: %s"), msg_utf8);
 	_qq_sys_msg_log_write(gc, message, from);